********************************************************************************
** WHAT I REALLY WANT - POLICY MAKER VIEWS ON EDUCATION IN EAST ASIA PACIFIC ***
** Noah Yarrow, Paul Cahu, Mary Breeding and Rythia Afkar 					 ***
** September 28, 2023 														 ***
** Printing data for the figures and tables of the paper					 ***
** Script author: Paul Cahu, pcahu@worldbank.org, paul.cahu@helloworld.bzh	 ***
********************************************************************************

** To be read: This script compiles the survey data and creates averages or 
** statistics for the countries in the survey
** Non-EAP countries are sometimes pooled and sometimes not depending of the figure
** External data is combined using usual sources such as WDI, UIS (unesco)
** Sources specified below
** [!!] Figures and tables are not rendered in order because some of them do not
** require the same data 
** [A] Figure 1,2,3,4, 6,7,8,9,10,12,13,14,17,19,22 are rendered first by combining 
** country stats derived from the survey and from international databases
** [B] Figures 18 and 21 are then rendered using only the survey's data
** [C] Figure 16 only uses external data
** [D] Figure 5/14 is directly produced in excel using the regression (probit)
** estimates and bounds presented at the end of the script.
** Thank you.

** [0] Loading data
** !!TO BE CUSTOMIZED TO RUN THE SCRIPT!!
global dir "C:/Users/wb614536/OneDrive - WBG/Documents/Reproducibility/20231016-What I really want-v3/files submitted/Package/Package/"
global output "${dir}/output"
*cd ${dir}
set varabbrev on
sysdir set PLUS "${dir}/ado"


** START OF THE SCRIPT
** [1] Loading external data by country ****************************************

** input external data to create the figures
** Violence to women, source: WHO
** Source: manual extraction from https://vaw-data.srhr.org/data
import excel "External_data.xlsx", sheet("Fig12") cellrange(B1:C13) firstrow clear
label var ipv_life "Intimate Partner Violence frequency over lifetime"
save "countries.dta",replace

** Women, Business and Law index
** Database copied-pasted from https://wbl.worldbank.org/content/dam/sites/wbl/documents/2023/WBL-1971-2023-Dataset.xlsx
import excel "External_data.xlsx", sheet("Fig13") firstrow clear
rename ISOCode cnt
keep if ReportYear==2023
keep cnt WBLINDEX
merge 1:1 cnt using "countries.dta"
keep if _merge==3
drop _merge
label var WBLINDEX "Women, Business and Law index 2023"
save "countries.dta",replace

** Share of public spending for education
** source: UNESCO sdg 4. http://sdg4-data.uis.unesco.org/
import excel "External_data.xlsx", sheet("Fig15") cellrange(A1:B13) firstrow clear
merge 1:1 cnt using "countries.dta"
drop _merge
label var Actual_budget_share "Share of public spending for education, 2021, UNESCO"
save "countries.dta",replace

** GDP per capita, WB Indicators
import excel "External_data.xlsx", sheet("GDP") firstrow clear
keep CountryCode YR2020 YR2021 CountryName
rename CountryCode cnt
rename CountryName country
drop if cnt==""
merge 1:1 cnt using "countries.dta"
keep if _merge==3
drop _merge
drop YR2020
rename YR2021 GDPc
destring GDPc, replace
label var GDPc "Per capita GDP, PPP 2021"
label var cnt "Country code"
save "countries.dta",replace

** Learning poverty estimates
** Source: 2022 update ttps://www.worldbank.org/en/topic/education/publication/state-of-global-learning-poverty
** And Paul Cahu and Lars Sondergaard (2023), Estimating interim learning poverty for Pacific
import excel "External_data.xlsx", sheet("Fig2") cellrange(A1:B21) firstrow clear
label var Learning_poverty "Learning poverty estimates"
label var cnt "Country code"
merge 1:1 cnt using "countries.dta"
drop _merge
** computing Non-EAP average
gen noneap=1
local list "IDN LAO MNG PHL SLB VNM VUT"
foreach x of local list {
replace noneap=0 if cnt=="`x'"
}
expand 3 if _n==_N
replace cnt="EAP average" if _n==_N
replace cnt="Non-EAP" if _n==_N-1
replace noneap=0 if cnt=="EAP average"
foreach var of varlist GDPc-ipv_life {
replace `var'=. if cnt=="EAP average"|cnt=="Non-EAP"
}
egen x=mean(Learning_poverty),by(noneap)
replace Learning_poverty=x if cnt=="EAP average"|cnt=="Non-EAP"
drop x
save "countries.dta",replace

** Actual returns of education from Patrinos and Montenegro
import excel "External_data.xlsx", sheet("Patrinos&Montenegro") cellrange(A1:E13) firstrow clear
** compute premium in %
foreach var of varlist premium* {
replace `var'=`var'-1
}
** compute average premium by gender
merge 1:1 cnt using "countries.dta"
drop _merge
replace country=cnt if cnt=="EAP average"|cnt=="Non-EAP"
save "countries.dta",replace

********************************************************************************
** [2.1] Loading CGD survey data 2020 to get LP guesses
use "CGD_2020.dta",clear
** The country names are not clearly stated however - we keep the ones for which
** we have estimated learning poverty numbers
** # 28 is Solomon Isl.
** # 34 is Vanuatu
** # 12 is Georgia
** # 3 is Benin
** # 5 if Cameroon
** # 4 is Burkina Faso
** # 25 is Pakistan
** # 30 is South Africa
** # 32 is Togo
** # 8 is Cote d'Ivoire
** # 6 is Comoros
** # 20 is Mali
** # 18 is Madagascar
** # 9 is DRC
** This can be checked by looking at the country in which officials did their studies
ta country_id country_studied1 if country_id==28|country_id==34
** kn learning measures the guess share of pupils who are proficient
** so this corresponds to 1-LP
gen cnt=""
local list "12 34 3 28 5 4 25 30 32 8 6 20 18 9"
local list2 "GEO VUT BEN SLB CMR BFA PAK ZAF TGO CIV COM MLI MDG COD"
forvalues i=1/14 {
local x:word `i' of `list'
local y:word `i' of `list2'
replace cnt="`y'" if country_id==`x'
}
drop if cnt==""
gen lpguess=1-kn_learning/100
keep cnt lpguess
drop if lpguess==.
** saving subset data to merge with 2022 data
save "lpguess.dta",replace
 
********************************************************************************
** [2.2] Loading CGD survey data 2022
use "CDG_2022.dta",clear

** Identifying EAP countries in the second wave
gen eap=0
local list "Indonesia Laos Philippines Mongolia Vietnam"
foreach x of local list {
replace eap=1 if country=="`x'"
}
label var eap "Country in EAP region"

** Adding labels and recoding
*** Teachers' attention to all students in class
label define tchatn_lab 1 "Those performing well" 2 "Those lagging behind" 3 "Both equally" 4 "Do not know/no answer"
label values teacher_attn tchatn_lab
ta country teacher_attn, nofreq row

*** reasons for low learning
label define l204 1 "Poverty" 2 "Malnutrition" 3 "Poor instruction" 4 "Lack of books and materials" 5 "Poor school facilities" 6 "Lack of internet" 7 "Other" 8 "don't know"
label values learning_reasons  l204

** recoding reasons linked to low learning
gen poor_education=1 if learning_reasons==3|learning_reasons==4|learning_reasons==5
replace poor_education=0 if learning_reasons!=8&poor_education==.
** recoding other reasons
** yes if only school factors
encode learning_reasons_other, gen(z)
local list "9 10 11 12 13 15 16 18 27 31 32 38 39 45 49 59 60 61 62 63 64 66 69 70 72 73 75 78 83 84 85 86 95 97 98 99 100 105 106 107"
foreach x of local list {
replace poor_education=1 if z==`x'
}
label var poor_education "Main reason for poor learning"
label define poor_lab 0 "External factors" 1 "Education systems flaws"
label values poor_education poor_lab
drop z

gen poverty_malnutrition=learning_reasons==1|learning_reasons==2

** Computing guessed learning poverty by mixing two gender responses
gen lpguess=learning_boys2
replace lpguess=learning_girls2 if lpguess=="NA"
destring lpguess,replace force
replace lpguess=1-lpguess/100
corr lpguess poor_education
label var lpguess "Guessed share of 10-yo who can't read properly"

** Adding country code
gen cnt="BGD" if country=="Bangladesh"
replace cnt="IDN" if country=="Indonesia"
replace cnt="LAO" if country=="Laos"
replace cnt="MNG" if country=="Mongolia"
replace cnt="PHL" if country=="Philippines"
replace cnt="VNM" if country=="Vietnam"
replace cnt="COD" if country=="DRC"
replace cnt="GHA" if country=="Ghana"
replace cnt="NGA" if country=="Nigeria"
replace cnt="PAK" if country=="Pakistan"
replace cnt="PER" if country=="Peru"
replace cnt="UGA" if country=="Uganda"
label var cnt "Country code"

** general labels
label define yesno 0 "No" 1 "Yes"

** creating countrycode to facilitate sorting between EAP and non EAP countries
gen cntd="eap "+cnt if eap==1
replace cntd="oth "+cnt if eap==0
** Country labels for eaP countries + "Non-eap" label
gen CNT=cnt if eap==1
replace CNT="Non-EAP" if eap==0

** process statements, agree/disagree
** label with initial coding
destring disability_equal_access,replace force
label define state 1 "Strongly agrees" 2 "Agrees" 3 "Disagrees" 4 "Strongly disagrees" 5 "Do not know"
foreach var of varlist edu_imprv ed_tech_equal_learning edu_imprv_gov_spending ed_tech_effective gov_subsidy_privateschl girls_addtionl_challenges promote_gender_equality mother_working contraception men_righttojob teacher_suspension disability_equal_access disability_accomdation {
label values `var' state 
}

********************************************************************************
** [3] Computing data for figures

** Preparation for FIGURE 2: combining guesses about learning poverty from the two waves
preserve
keep cnt lpguess
drop if lpguess==.
append using "lpguess.dta"
gen eap=0
local list "IDN LAO MNG VNM SLB VUT PHL"
foreach x of local list {
replace eap=1 if cnt=="`x'"
}
label var eap "Country in EAP region"
egen x=mean(lpguess),by(cnt)
egen y=mean(x),by(eap)
sort cnt
drop if cnt==cnt[_n-1]
drop lpguess
sort eap
expand 2 if _n==_N
expand 2 if _n==1
replace cnt="EAP average" if _n==_N-1
replace cnt="Non-EAP" if _n==_N
replace x=y if cnt=="EAP average"|cnt=="Non-EAP"
keep cnt x
rename x lpguess
label var lpguess "Learning poverty rate guessed by officials"
merge 1:1 cnt using "countries.dta"
drop _merge
save "countries.dta",replace


** Preparation for FIGURE 1: Officials prioritize improvements to school completion over improvements to learning for economic growth
*** Should quality (test-scores) or quantity (access to secondary school be the priority?
restore
gen economy_improvement=economy_improvement_male
replace economy_improvement=economy_improvement_female if economy_improvement_male=="NA"
gen other_statements=economy_improvement_other_male if economy_improvement_male=="4"
replace other_statements=economy_improvement_other_female if economy_improvement_female=="4"

gen quality=economy_improvement=="2"
replace quality=. if economy_improvement=="3"
replace quality=. if economy_improvement=="4"

** we then split the other statements in two columns
encode other_statements,gen(os)
local list "38 40 41 42 55 56 68 59 62 70 72 73 74 87 93 98 99"
foreach x of local list {
replace quality=1 if os==`x'
}
local list "6 7 8 9 10 11 18 19 29 30 31 33 34 35 39 45 46 47 48 49 50 51 52 53 57 78 79 80 91 92 94 95 102 104"
foreach x of local list {
replace quality=0 if os==`x'
}
gen schooling_over_scores=1-quality

** computing national statistics for all countries
egen x1=mean(schooling_over_score) if orggroup=="MOE",by(cnt)
egen x2=mean(schooling_over_score) if orggroup=="MOF",by(cnt)
egen x3=mean(schooling_over_score),by(cnt)
egen x11=mean(x1),by(cnt)
egen x21=mean(x2),by(cnt)
egen x31=mean(x3),by(cnt)
label var x11 "MOE"
label var x21 "MOF"
label var x31 "All"
rename x11 schooling_over_score_moe
rename x21 schooling_over_score_mof
rename x31 schooling_over_score_all
drop x1 x2 x3
** computing regional statistics
egen x1=mean(schooling_over_scores) if orggroup=="MOE",by(eap)
egen x2=mean(schooling_over_scores) if orggroup=="MOF",by(eap)
egen x3=mean(schooling_over_scores),by(eap)
egen x11=mean(x1),by(eap)
egen x21=mean(x2),by(eap)
egen x31=mean(x3),by(eap)
drop x1 x2 x3
** replacing national statistics by regional statistics for non-eap countries
rename x11 schooling_over_score_moe_regiona
rename x21 schooling_over_score_mof_regiona
rename x31 schooling_over_score_all_regiona

** Preparation for FIGURE 3 ****************************************************
** recoding barrier learning
gen bl=barrier_learning
label var bl "Main barrier to learning recoded"
recode bl (11=1) (1=2) (2=3) (3=4) (10=5) (12=6) (13=7) (14=8)
label define blo_lab 1 "Implementation capacity" 2 "Money" 3 "Lack of interest from government" 4 "Political resistance from others" 5 "Political resistance from teachers' union" 6 "Others" 7 "No barrier" 8 "No answer"
label values bl blo_lab

gen total_bl=0
forvalues i=1/8 {
egen bl_`i'=sum(bl==`i'),by(cnt)
replace total_bl=total_bl+bl_`i'
}

forvalues i=1/8 {
replace bl_`i'=bl_`i'/total_bl
}
label var bl_1 "Main barrier to learning: Implementation capacity"
label var bl_2 "Main barrier to learning: Money"
label var bl_3 "Main barrier to learning: Lack of interest from government"
label var bl_4 "Main barrier to learning: Political resistance from others"
label var bl_5 "Main barrier to learning: Political resistance from teachers' unions"
label var bl_6 "Main barrier to learning: Other"
label var bl_7 "Main barrier to learning: No barrier"
label var bl_8 "Main barrier to learning: No answer"
drop total_bl

** regional stats
gen total_bl=0
forvalues i=1/8 {
egen bl_`i'_regional=sum(bl==`i'),by(eap)
replace total_bl=total_bl+bl_`i'_regional
}

forvalues i=1/8 {
replace bl_`i'_regional=bl_`i'_regional/total_bl
}
drop bl total_bl


** Preparation for FIGURE 4 ****************************************************
egen x1=mean(poor_educatio),by(cnt)
egen x2=mean(poverty_malnutrition),by(cnt)
label var x1 "Respondants attributing low learning to school factors"
label var x2 "Respondants attributing low learning to poverty & malnutrition"
rename x1 school_factors
rename x2 poverty_and_malnutrition
** Preparation for FIGURE 4 ****************************************************
egen x1=mean(poor_educatio),by(eap)
egen x2=mean(poverty_malnutrition),by(eap)
rename x1 school_factors_regional
rename x2 poverty_and_malnutrition_regiona

** Preparation for FIGURE 6 ****************************************************
** Recoding beliefs on a likert scale by droping "no answer" responses
foreach var of varlist ed_tech_equal_learning edu_imprv_gov_spending ed_tech_effective gov_subsidy_privateschl girls_addtionl_challenges promote_gender_equality mother_working contraception men_righttojob teacher_suspension disability_equal_access disability_accomdation{
destring `var',replace force
label values `var' state
gen `var'_m=`var'
replace `var'_m=. if `var'==5
label values `var'_m state
}
foreach var of varlist ed_tech_effective ed_tech_equal_learning girls_addtionl_challenges mother_working {
gen `var'_s=`var'_m
recode `var'_s (1=2) (2=1) (3=-1) (4=-2) (5=0)
gen `var'_a=`var'_m==1|`var'_m==2
}

egen x1=mean(ed_tech_effective_a),by(cnt)
egen x2=mean(ed_tech_equal_learning_a),by(cnt)
label var x1 "'EdTech (e.g. Internet, TV, radio, or mobile) was effective in supporting student learning during COVID-related school closures.'"
label var x2 "'EdTech helps all children learn equally.'"
rename x1 EdTech_covid
rename x2 EdTeach_equality

** computing the statistics for the EAP average
egen x1=mean(ed_tech_effective_a),by(eap)
egen x2=mean(ed_tech_equal_learning_a),by(eap)

rename x1 EdTech_covid_regional
rename x2 EdTeach_equality_regional

** Preparation for FIGUREs 7 and 8 *********************************************
local list "disability_equal_access disability_accomdation promote_gender_equality  girls_addtionl_challenges"
local list2 "fig7a fig7b fig8a fig8b"
forvalues i=1/4 {
local x:word `i' of `list'
local y:word `i' of `list2'
forvalues j=1/5 {
egen `y'_`j'=mean(`x'==`j'),by(cnt)
egen `y'_`j'_regional=mean(`x'==`j'),by(eap)
}
label var `y'_1 "`x': Strongly agrees"
label var `y'_2  "`x': Agrees"
label var `y'_3  "`x': Disagrees"
label var `y'_4  "`x': Strongly disagrees"
label var `y'_5  "`x': Does not know"
}

** TABLE 4: Factor analysys of views about inclusion
factor promote_gender_equality_m men_righttojob_m teacher_suspension_m disability_equal_access_m disability_accomdation_m
estat kmo
predict inclusion
** check the sign
ta promote_gender_equality, su(inclusion)
** sign should be changed
replace inclusion=-inclusion
** testing the two groups
ttest inclusion,by(eap)
** the averages are different at 5%.

** Preparation for FIGURE 9 ****************************************************
egen inclusion_index=mean(inclusion),by(cnt)
egen inclusion_index_regional=mean(inclusion),by(eap)

** TABLE 1: Average index of gender/disability equality by opinion about the justification of violence toward children
** recoding violence against children
gen violence_parents=1 if parents_beating==2
replace violence_parents=2 if parents_beating==3
replace violence_parents=3 if parents_beating==1

gen violence_teachers=1 if teachers_beating==2
replace violence_teachers=2 if teachers_beating==3
replace violence_teachers=3 if teachers_beating==1

label define vio_lab 1 "Never justified" 2 "Sometimes justified" 3 "always justified"
label values violence_teachers violence_parents vio_lab

gen violence_rate=perc_boys_sexual_violence2 if perc_boys_sexual_violence2!="NA"
replace violence_rate=perc_girls_sexual_violence2 if perc_girls_sexual_violence2!="NA"
destring violence_rate,replace force

* create table16 program 

capture program drop table16

program define table16
    version 16 : table `0' 
end

table16 violence_parents,c(mean inclusion)
table16 violence_teachers,c(mean inclusion)

table16 violence_parents,c(mean inclusion)
table16 violence_teachers,c(mean inclusion)

** Preparation for FIGURES 10 **************************************************
local list "violence_parents violence_teachers"
local list2 "fig10a fig10b"
forvalues i=1/2 {
local w:word `i' of `list'
local x:word `i' of `list2'
gen total_x=0
forvalues j=1/3 {
egen `x'_`j'=mean(`w'==`j'),by(cnt)
replace total_x=total_x+`x'_`j'
}
label var `x'_1 "Never"
label var `x'_2  "Something in between"
label var `x'_3  "Always"
forvalues j=1/3 {
replace `x'_`j'=`x'_`j'/total_x
}
drop total_x
}
** regional stats
local list "violence_parents violence_teachers"
local list2 "fig10a fig10b"
forvalues i=1/2 {
local w:word `i' of `list'
local x:word `i' of `list2'
gen total_x=0
forvalues j=1/3 {
egen `x'_`j'_regional=mean(`w'==`j'),by(eap)
replace total_x=total_x+`x'_`j'_regional
}
label var `x'_1_regional "Never"
label var `x'_2_regional  "Something in between"
label var `x'_3_regional  "Always"
forvalues j=1/3 {
replace `x'_`j'_regional=`x'_`j'_regional/total_x
}
drop total_x
}


** Preparation for FIGURE 11 ***************************************************
gen violence=1 if violence_teachers==1&violence_parents==1
replace violence=2 if violence_teachers==2&violence_parents<3
replace violence=2 if violence_parents==2&violence_teachers<3
replace violence=3 if violence_teachers==3&violence_parents<3
replace violence=3 if violence_parents==3&violence_teachers<3
replace violence=4 if violence_teachers==3&violence_parents==3
label define vio2_lab 1 "Never justified for both parents and teachers" 2 "Sometimes justified for either parents and teachers" 3 "Always justified for either parents and teachers" 4 "Always justified for both parents and teachers"
label values violence vio2_lab

gen total_violence=0
forvalues i=1/4 {
egen violence_`i'=mean(violence==`i'),by(cnt)
replace total_violence=total_violence+violence_`i'
}
forvalues i=1/4 {
replace  violence_`i'= violence_`i'/total_violence
}
drop total_violence
local list "Never Sometimes_for_either Always_for_either_parents_teachers Always_for_both_parents_teachers"
forvalues i=1/4 {
local w:word `i' of `list'
label var violence_`i' "Violence: `w'"
}
gen total_violence=0
forvalues i=1/4 {
egen violence_`i'_regional=mean(violence==`i'),by(eap)
replace total_violence=total_violence+violence_`i'_regional
}
forvalues i=1/4 {
replace  violence_`i'_regional= violence_`i'_regional/total_violence
}
drop total_violence
local list "Never Sometimes_for_either Always_for_either_parents_teachers Always_for_both_parents_teachers"
forvalues i=1/4 {
local w:word `i' of `list'
label var violence_`i'_regional "Violence (reg): `w'"
}

** Preparation for FIGURE 12 ***************************************************
** We inverse the coding of the promote_gender_equality variable which is now coded from 1 to 5
gen inv_promote_gender_equality=6-promote_gender_equality_m
egen fig12_gender_equality=mean(inv_promote_gender_equality),by(cnt)

** Preparation for FIGURE 15 ***************************************************
destring spending_desired2 spending_shareofbudget2,replace force

egen pub_fund_desired=mean(spending_desired2),by(cnt)
egen pub_fund_desired_regional=mean(spending_desired2),by(eap)
egen pub_fund_guessed=mean(spending_shareofbudget2),by(cnt)
egen pub_fund_guessed_regional=mean(spending_shareofbudget2),by(eap)


** Preparation for FIGURE 17  **************************************************
local list "Strongly_agrees Agrees Disagrees Strongly_disagrees Does_not_know"
forvalues i=1/5 {
egen fig17_`i'=mean(edu_imprv_gov_spending==`i'),by(cnt)
local w:word `i' of `list'
label var fig17_`i' "More money won't matter: `w'" 
}
** regional stats
forvalues i=1/5 {
egen fig17_`i'_regional=mean(edu_imprv_gov_spending==`i'),by(eap)
local w:word `i' of `list'
label var fig17_`i'_regional "More money won't matter: `w'" 
}

** Preparation for FIGURE 18  **************************************************
gen money_barrier=barrier_learning==1
label variable money_barrier "Selected money as the main barrier to improving learning"
label define mb_lab 0 "Did not select money as the main barrier to improving learning" 1 "Selected money as the main barrier to improving learning"
label values money_barrier mb_lab
local list "Strongly_agrees Agrees Disagrees Strongly_disagrees Does_not_know"
forvalues i=1/5 {
egen fig18_`i'=mean(edu_imprv_gov_spending==`i'),by(money_barrier)
local w:word `i' of `list'
label var fig18_`i' "`w'" 
}

** Preparation for FIGURE 19/20/22  ********************************************
destring primary_earnings_female secondary_earnings_female tvet_earnings_female university_earnings_female  primary_earnings_male secondary_earnings_male tvet_earnings_male university_earnings_male,replace force
gen ret_12m=secondary_earnings_male/primary_earnings_male-1
gen ret_12f=secondary_earnings_female/primary_earnings_female-1
gen ret_tvetm=tvet_earnings_male/secondary_earnings_male-1
gen ret_tvetf=tvet_earnings_female/secondary_earnings_female-1
gen ret_23m=university_earnings_male/secondary_earnings_male-1
gen ret_23f=university_earnings_female/secondary_earnings_female-1
gen ret_12mf=ret_12m
replace ret_12mf=ret_12f if ret_12mf==.
gen ret_23mf=ret_23m
replace ret_23mf=ret_23f if ret_23mf==.
gen ret_tvetmf=ret_tvetm
replace ret_tvetmf=ret_tvetf if ret_tvetmf==.

egen fig19a=mean(ret_12mf), by(cnt)
egen fig19b=mean(ret_23mf), by(cnt)
egen fig19a_regional=mean(ret_12mf), by(eap)
egen fig19b_regional=mean(ret_23mf), by(eap)

egen fig22_12m=mean(ret_12m), by(cnt)
egen fig22_23m=mean(ret_23m), by(cnt)
egen fig22_12f=mean(ret_12f), by(cnt)
egen fig22_23f=mean(ret_23f), by(cnt)



** Saving micro data
save "CDG_2022_for_figures.dta",replace
use  "CDG_2022_for_figures.dta",clear
** [4] PREPARING COUNTRY DATASET ***********************************************
keep cnt CNT eap economy_improvement-fig22_23f
drop ret_12m-ret_tvetmf
drop money_barrier money_barrier inv_promote_gender_equality violence ed_tech_equal_learning_m -mother_working_a
drop other_statements economy_improvement quality os schooling_over_scores inclusion
drop violence_parents violence_teachers violence_rate
sort cnt
drop if cnt==cnt[_n-1]
drop fig18*
** adding one line for Non-EAP and putting variables in it
expand 2 if cnt=="BGD"
replace cnt="Non-EAP" if _n==_N
** adding one line for EAP average and computing all the variables
expand 2 if cnt=="VNM"
replace cnt="EAP average" if _n==_N
** Filling up regional stats
*foreach var of varlist bl_1-bl_8 school_factors EdTech_covid EdTeach_equality inclusion_index fig10a_1-fig10b_3 violence_1-violence_4 pub_fund_desired pub_fund_guessed fig17_1-fig17_5 fig19a fig19b {
foreach var of varlist bl_1-bl_8 school_factors EdTech_covid EdTeach_equality inclusion_index fig10a_1-fig10b_3 violence_1-violence_4 pub_fund_desired pub_fund_guessed fig17_1-fig17_5 fig19a fig19b fig7a_1 fig7a_2 fig7a_3 fig7a_4 fig7a_5 fig7b_1 fig7b_2 fig7b_3 fig7b_4 fig7b_5 fig8a_1 fig8a_2 fig8a_3 fig8a_4 fig8a_5 fig8b_1 fig8b_2 fig8b_3 fig8b_4 fig8b_5 {
replace `var'=`var'_regional if cnt=="Non-EAP"|cnt=="EAP average"
drop `var'_regional
}
replace poverty_and_malnutrition=poverty_and_malnutrition_regiona if cnt=="Non-EAP"|cnt=="EAP average"
foreach var of varlist schooling_over_score_moe schooling_over_score_mof schooling_over_score_all {
replace `var'=`var'_reg if cnt=="Non-EAP"|cnt=="EAP average"
}

merge 1:1 cnt using "countries.dta"
drop _merge
replace country=cnt if cnt=="Non-EAP"|cnt=="EAP average"

save "countries.dta",replace


********************************************************************************
*** [5] DISPLAYING FIGURES 
********************************************************************************
use "countries.dta",clear
** DISPLAY FIGURE 1 ************************************************************
gen order=1 if cnt=="MNG"
replace order=2 if cnt=="LAO"
replace order=3 if cnt=="PHL"
replace order=4 if cnt=="IDN"
replace order=5 if cnt=="VNM"
replace order=6 if cnt=="Non-EAP"
label define order_lab 1 "MNG" 2 "LAO" 3 "PHL" 4 "IDN" 5 "VNM" 6 "Non-EAP"
label values order order_lab
** stata figure - replicating excel figure
graph bar (asis) schooling_over_score_moe schooling_over_score_mof schooling_over_score_all , over(order) ytitle("Share of officials choosing increase number of students finishing secondary instead of mprove test scores", size(vsmall)) bar(1,color("223 83 39")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall)) bargap(10)
graph save Graph "${output}/fig_1", replace
** table output to paste into excel
table16 order,c(mean schooling_over_score_moe mean schooling_over_score_mof mean schooling_over_score_all)
** F test
reg schooling_over_score_all GDPc

** DISPLAY FIGURE 2 ************************************************************
label var Learning_poverty "Actual estimates"
label var lpguess "Estimated by officials"
drop order
gen order=1 if cnt=="VNM"
replace order=2 if cnt=="MNG"
replace order=3 if cnt=="IDN"
replace order=4 if cnt=="LAO"
replace order=5 if cnt=="PHL"
replace order=6 if cnt=="VUT"
replace order=7 if cnt=="SLB"
replace order=8 if cnt=="EAP average"
replace order=9 if cnt=="Non-EAP"
label drop order_lab
label define order_lab 1 "Vietnam" 2 "Mongolia" 3 "Indonesia" 4 "Lao PDR" 5 "Philippines" 6 "Vanuatu" 7 "Solomon Is." 8 "EAP average" 9 "Non-EAP"
label values order order_lab
** stata figure - replicating excel figure
graph bar (asis) lpguess Learning_poverty , over(order,label(labsize(vsmall))) ytitle("Guessed and actual learning poverty", size(vsmall)) bar(1,color("223 83 39")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall)) bargap(10)
graph save Graph "${output}/fig_2", replace
** table output to paste into excel
table16 order,c(mean lpguess mean Learning_poverty )
** F test
reg lpguess GDPc
** also rejected at 5% threshold

** DISPLAY FIGURE 3 ************************************************************
drop order
gen order=1 if cnt=="IDN"
replace order=2 if cnt=="PHL"
replace order=3 if cnt=="VNM"
replace order=4 if cnt=="MNG"
replace order=5 if cnt=="LAO"
replace order=6 if cnt=="Non-EAP"
label drop order_lab
label define order_lab 1 "Indonesia" 2 "Philippines" 3 "Vietnam" 4 "Mongolia" 5 "Lao PDR" 6 "Non-EAP"
label values order order_lab
** stata figure - replicating excel figure
graph bar (asis) bl_* , over(order,label(labsize(vsmall))) ytitle("Largest barrier to improving student learning according to officials", size(vsmall)) bar(1,color("223 83 39")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("131 131 131")) bar(5,color("254 195 6")) bar(6,color("65 138 179")) bar(7,color("39 83 107")) bar(8,color("100 110 23")) legend(size(vsmall))  ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall)) stack
graph save Graph "${output}/fig_3", replace
** table output to paste into excel
table16 order,c(mean bl_1 mean bl_2 mean bl_3 mean bl_4 mean bl_5)
table16 order,c(mean bl_6 mean bl_7 mean bl_8)
** F test
reg bl_1 GDPc
** also rejected at 5% threshold

** DISPLAY FIGURE 4 ************************************************************
drop order
label drop order_lab
gen order=1 if cnt=="LAO"
replace order=2 if cnt=="PHL"
replace order=3 if cnt=="IDN"
replace order=4 if cnt=="VNM"
replace order=5 if cnt=="MNG"
replace order=6 if cnt=="Non-EAP"
label define order_lab 1 "LAO" 2 "PHL" 3 "IDN" 4 "VNM" 5 "MNG" 6 "Non-EAP"
label values order order_lab
** stata figure - replicating excel figure
graph bar (asis) lpguess school_factors poverty_and_malnutrition , over(order,label(labsize(vsmall))) ytitle("Share of officials", size(vsmall)) bar(1,color("223 83 39")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) legend(size(vsmall)) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_4", replace
** table output to paste into excel
table16 order,c(mean lpguess mean school_factors mean poverty_and_malnutrition)
** F test
reg school_factors GDPc
reg poverty_and_malnutrition GDPc
** also rejected at 5% threshold


** DISPLAY FIGURE 6 ************************************************************
drop order
label drop order_lab
gen order=1 if cnt=="MNG"
replace order=2 if cnt=="PHL"
replace order=3 if cnt=="LAO"
replace order=4 if cnt=="IDN"
replace order=5 if cnt=="VNM"
replace order=6 if cnt=="EAP average"
replace order=7 if cnt=="Non-EAP"
label define order_lab 1 "MNG" 2 "PHL" 3 "LAO" 4 "IDN" 5 "VNM" 7 "Non-EAP" 6 "EAP average"
label values order order_lab
** stata figure - replicating excel figure
graph bar (asis) EdTech_covid EdTeach_equality, over(order,label(labsize(vsmall))) ytitle("Share of officials agreeing", size(vsmall)) bar(1,color("223 83 39")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) legend(size(vsmall) rows(2)) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
** table output to paste into excel
table16 order,c(mean EdTech_covid  mean EdTeach_equality)
** F test
reg EdTeach_equality GDPc
reg EdTech_covid GDPc
** also rejected at 5% threshold

** DISPLAY FIGURE 7 AND 8 ******************************************************
drop order
label drop order_lab
gen order=1 if cnt=="IDN"
replace order=2 if cnt=="LAO"
replace order=3 if cnt=="MNG"
replace order=4 if cnt=="PHL"
replace order=5 if cnt=="VNM"
replace order=6 if cnt=="Non-EAP"
label define order_lab 1 "IDN" 2 "LAO" 3 "MNG" 4 "PHL" 5 "VNM" 6 "Non-EAP"
label values order order_lab
local list "fig7a_ fig7b_ fig8a_ fig8b_"
local list2 "Strongly_agrees Agrees Disagrees Strongly_disagress Does_not_know"
forvalues i=1/4 {
local w:word `i' of `list'
forvalues j=1/5 {
local x:word `j' of `list2'
label var `w'`j' "`x'"
}
}
** stata figure - replicating excel figure
graph bar (asis) fig7a_1-fig7a_5, over(order,label(labsize(vsmall)))  bar(1,color("83 92 19")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_7a", replace
graph bar (asis) fig7b_1-fig7b_5 , over(order)  bar(1,color("83 92 19")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_7b", replace
graph bar (asis) fig8a_1-fig8a_5 , over(order)  bar(1,color("83 92 19")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_8a", replace
graph bar (asis) fig8b_1-fig8b_5, over(order)  bar(1,color("83 92 19")) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_8b", replace
** table output to paste into excel
table16 order,c(mean fig7a_1 mean fig7a_2 mean fig7a_3 mean fig7a_4 mean fig7a_5)
table16 order,c(mean fig7b_1 mean fig7b_2 mean fig7b_3 mean fig7b_4 mean fig7b_5)
table16 order,c(mean fig8a_1 mean fig8a_2 mean fig8a_3 mean fig8a_4 mean fig8a_5)
table16 order,c(mean fig8b_1 mean fig8b_2 mean fig8b_3 mean fig8b_4 mean fig8b_5)

** F test
reg fig7a_1 GDPc
reg fig7b_1 GDPc
reg fig8a_1 GDPc
** also rejected at 5% threshold
reg fig8b_3 GDPc
reg fig8b_3 GDPc eap
** There is a correlation between the rejection and GDPc but it disappears once
** we account for EAP/non-EAP

** DISPLAY FIGURE 9 ************************************************************
drop order
label drop order_lab
gen order=13 if cnt=="EAP average"
replace order=14 if cnt=="Non-EAP"
local list "LAO VNM IDN MNG PHL PAK UGA BGD GHA NGA PER COD"
forvalues i=1/12 {
local w:word `i' of `list'
replace order=`i' if cnt=="`w'"
}
label define order_lab  1 "Lao PDR" 2 "Vietnam"  3 "Indonesia" 4 "Mongolia" 5 "Philippines" 6 "Pakistan" 7 "Uganda" 8 "Bangladesh" 9 "Ghana" 10 "Nigeria" 11 "Peru" 12 "DRC" 13 "EAP-average" 14 "Non-EAP"
label values order order_lab
label var inclusion_index "Gender/disability equity index"
** stata figure - replicating excel figure
graph bar (asis) inclusion_index, over(order, label(labsize(tiny))) bar(1,color("166 183 39")) ylabel(-0.8(0.2)0.8,labsize(vsmall)) blabel(,position(outside))
graph save Graph "${output}/fig_9", replace
** table output to paste into excel
table16 order,c(mean inclusion_index)
** F test
reg inclusion_index GDPc
** also rejected at 5% threshold

** DISPLAY FIGURES 10 **********************************************************
drop order
label drop order_lab
gen order=1 if cnt=="IDN"
replace order=2 if cnt=="LAO"
replace order=3 if cnt=="MNG"
replace order=4 if cnt=="PHL"
replace order=5 if cnt=="VNM"
replace order=6 if cnt=="Non-EAP"
label define order_lab 1 "IDN" 2 "LAO" 3 "MNG" 4 "PHL" 5 "VNM" 6 "Non-EAP"
label values order order_lab

** stata figure - replicating excel figure
graph bar (asis) fig10a_1-fig10a_3, over(order,label(labsize(vsmall)))  bar(1,color("166 183 39")) bar(2,color("246 146 0")) bar(3,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small) rows(1)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_10a", replace
graph bar (asis) fig10b_1-fig10b_3 , over(order,label(labsize(vsmall))) bar(1,color("166 183 39")) bar(2,color("246 146 0")) bar(3,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small) rows(1)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_10b", replace
** table output to paste into excel
table16 order,c(mean fig10a_1 mean fig10a_2 mean fig10a_3)
table16 order,c(mean fig10b_1 mean fig10b_2 mean fig10b_3)
** F test
reg fig10a_1 GDPc
** also rejected at 5% threshold
reg fig10b_1 GDPc
** There is a correlation between the rejection and GDPc but it disappears once
** we account for EAP/non-EAP
reg fig10b_1 GDPc eap

** DISPLAY FIGURE 11 ***********************************************************
replace order=7 if order==6
replace order=6 if cnt=="EAP average"
label drop order_lab
label define order_lab 1 "IDN" 2 "LAO" 3 "MNG" 4 "PHL" 5 "VNM" 6 "EAP average" 7 "Non-EAP"
label values order order_lab

label var violence_1 "Never justified for both parents and teachers" 
label var violence_2 "Sometimes justified for either parents and teachers"
label var violence_3 "Always justified for either parents and teachers"
label var violence_4 "Always justified for both parents and teachers"

** stata figure - replicating excel figure
graph bar (asis) violence_1-violence_4, over(order,label(labsize(vsmall)))  bar(1,color("166 183 39")) bar(3,color("246 146 0")) bar(4,color("223 83 39"))  bar(2,color("254 195 6"))  legend(size(small) rows(4)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_11", replace
** table output to paste into excel
table16 order,c(mean violence_1 mean violence_2 mean violence_3 mean violence_4)
** F test
reg violence_1 GDPc
reg violence_1 GDPc eap

** DISPLAY FIGURE 12 ***********************************************************
** stata figure - replicating excel figure
twoway (scatter fig12_gender_equality ipv, mlabel(country)) (lfit fig12_gender_equality ipv), legend(off) ylabel(4(0.1)4.8,labsize(small)) xlabel(0(10)70)
graph save Graph "${output}/fig_12", replace
** table output to paste into excel
table16 country if ipv!=.,c(mean fig12_gender_equality mean ipv)

** DISPLAY FIGURE 13 ***********************************************************
** stata figure - replicating excel figure
twoway (scatter fig12_gender_equality WBLINDEX, mlabel(country)) (lfit fig12_gender_equality WBLINDEX), legend(off) ylabel(4(0.1)4.8,labsize(small)) xlabel(40(10)100)
graph save Graph "${output}/fig_13", replace
** table output to paste into excel
table16 country if ipv!=.,c(mean fig12_gender_equality mean WBLINDEX mean eap)

** DISPLAY FIGURE 15 ***********************************************************
drop order
label drop order_lab
gen order=1 if cnt=="LAO"
replace order=2 if cnt=="PHL"
replace order=3 if cnt=="VNM"
replace order=4 if cnt=="IDN"
replace order=5 if cnt=="MNG"
replace order=6 if cnt=="EAP average" 
replace order=7 if cnt=="Non-EAP"
label define order_lab 1 "LAO" 2 "PHL" 3 "VNM" 4 "IDN" 5 "MNG" 6 "EAP average" 7 "Non-EAP"
label values order order_lab
** Dividing par 100 to get percentages
foreach var of varlist pub_fund_guessed Actual_budget_share pub_fund_desired {
replace `var'=`var'/100
}
label var pub_fund_guessed "Estimated budget share"
label var pub_fund_desired "Officials' preferred budget share"
label var Actual_budget_share "Actual budget share"
egen x=mean(Actual_budget_share),by(eap)
replace Actual_budget_share=x if cnt=="EAP average"|cnt=="Non-EAP"
drop x
** stata figure - replicating excel figure
graph bar (asis) pub_fund_guessed Actual_budget_share pub_fund_desired, over(order,label(labsize(vsmall))) ytitle("Share of public spending for education",size(small)) bar(2,color("166 183 39")) bar(3,color("246 146 0")) bar(1,color("223 83 39"))  legend(size(vsmall) rows(1)) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%",labsize(vsmall)) bargap(10)
graph save Graph "${output}/fig_15", replace
** table output to paste into excel
table16 order,c(mean pub_fund_guessed mean Actual_budget_share mean pub_fund_desired)

** DISPLAY FIGURE 17 ***********************************************************
drop order
label drop order_lab
gen order=1 if cnt=="PHL"
replace order=2 if cnt=="IDN"
replace order=3 if cnt=="VNM"
replace order=4 if cnt=="MNG"
replace order=5 if cnt=="LAO"
replace order=6 if cnt=="Non-EAP"
label define order_lab 1 "PHL" 2 "IDN" 3 "VNM" 4 "MNG" 5 "LAO" 6 "Non-EAP"
label values order order_lab
local list "Strongly_agrees Agrees Disagrees Strongly_disagress Does_not_know"
forvalues i=1/5 {
local w:word `i' of `list'
label var fig17_`i' "`w'"
}

** stata figure - replicating excel figure
graph bar (asis)  fig17_1 fig17_2 fig17_5 fig17_3 fig17_4,over(order,label(labsize(vsmall))) ytitle("Share of officials believing that more money will not improve learning",size(vsmall)) bar(1,color("83 92 19")) bar(2,color("166 183 39")) bar(3,color("254 195 6")) bar(4,color("246 146 0"))  bar(5,color("223 83 39"))  legend(size(vsmall) rows(1)) stack ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%" .6 "60%" 0.7 "70%" .8 "80%" .9 "90%" 1 "100%",labsize(vsmall))
graph save Graph "${output}/fig_17", replace
** table output to paste into excel
table16 order,c(mean fig17_1 mean fig17_2 mean fig17_3 mean fig17_4 mean fig17_5)
** F test
gen fig17_12=fig17_2+fig17_1
reg fig17_12 GDPc
** Not significant at 5% threshold

** DISPLAY FIGURE 19 ***********************************************************
drop order
label drop order_lab
gen order=1 if cnt=="Non-EAP"
replace order=2 if cnt=="EAP average"
replace order=3 if cnt=="VNM"
replace order=4 if cnt=="PHL"
replace order=5 if cnt=="MNG"
replace order=6 if cnt=="LAO"
replace order=7 if cnt=="IDN"
label define order_lab 1 "Non-EAP" 2 "EAP average" 3 "VNM" 4 "PHL" 5 "MNG" 6 "LAO" 7 "IDN"
label values order order_lab
** stata figure - replicating excel figure
graph hbar fig19b fig19a , over(order,label(labsize(vsmall))) legend(label(1 "Tertiary vs. secondary education completed") label(2 "Secondary vs. primary education completed") size(vsmall)) bar(1,color("166 183 39"))  bar(2,color("65 138 179")) ylabel(0(0.2)1.8,labsize(vsmall))
graph save Graph "${output}/fig_19", replace
** table output to paste into excel
table16 order, c(mean fig19a mean fig19b)


** DISPLAY FIGURE 20 ***********************************************************
drop order
label drop order_lab
gen order=1 if cnt=="IDN"
replace order=2 if cnt=="LAO"
replace order=3 if cnt=="MNG"
replace order=4 if cnt=="PHL"
replace order=5 if cnt=="VNM"
label define order_lab 1 "Indonesia" 2 "Lao PDR" 3 "Mongolia" 4 "Philippines" 5 "Vietnam"
label values order order_lab
gen premium_sec=(premium_sec_over_prim_males+premium_sec_over_prim_females)/2
gen premium_ter=(premium_ter_over_sec_males+premium_ter_over_sec_females)/2

** stata figure - replicating excel figure
graph bar fig19a premium_sec, over(order,label(labsize(vsmall))) legend(label(1 "Expected") label(2 "Actual") size(vsmall)) bar(1,color("254 195 6"))  bar(2,color("166 183 39")) bargap(10) ylabel(0 "0%" .2 "20%" .4 "40%" .6 "60%" .8 "80%" 1 "100%" 1.2 "120%" 1.4 "140%" 1.6 "160%" 1.8 "180%",labsize(vsmall))
graph bar fig19b premium_ter, over(order,label(labsize(vsmall))) legend(label(1 "Expected") label(2 "Actual") size(vsmall)) bar(1,color("254 195 6"))  bar(2,color("166 183 39")) bargap(10) ylabel(0 "0%" .2 "20%" .4 "40%" .6 "60%" .8 "80%" 1 "100%" 1.2 "120%" 1.4 "140%" 1.6 "160%" 1.8 "180%",labsize(vsmall))
graph save Graph "${output}/fig_20", replace
** table output to paste into excel
table16 order, c(mean fig19a mean premium_sec mean fig19b mean premium_ter)

** DISPLAY FIGURE 22 ***********************************************************
gen gap_sec_m=fig22_12m-premium_sec_over_prim_males
gen gap_sec_f=fig22_12f-premium_sec_over_prim_females
gen gap_ter_m=fig22_23m-premium_ter_over_sec_males
gen gap_ter_f=fig22_23f-premium_ter_over_sec_females

label var gap_sec_m "Secondary vs. primary Male"
label var gap_sec_f "Secondary vs. primary Female"
label var gap_ter_m "University vs. secondary Male"
label var gap_ter_f "University vs. secondary Female"


** stata figure - replicating excel figure
graph bar gap_sec_m gap_sec_f gap_ter_m gap_ter_f, over(order,label(labsize(vsmall))) bargap(10) legend(rows(2) cols(2)) ylabel(-0.8(0.2)1.2) bar(1,color(blue)) bar(2,color(green)) bar(3,color(orange)) bar(4,color(gray))
graph save Graph "${output}/fig_22", replace
** table output to paste into excel
table16 order,c(mean gap_sec_m mean gap_sec_f mean  gap_ter_m mean gap_ter_f)

** One needs to get back to the microdata to print figures 18 and 21 ***********
** DISPLAY FIGURE 18 ***********************************************************

use "CDG_2022_for_figures.dta",clear
sort money_barrier
drop if money_barrier==money_barrier[_n-1]
** stata figure - replicating excel figure
graph bar (asis) fig18_* , over(money_barrier,label(labsize(vsmall))) ytitle("Share of officials agreeing with more money won't impact learning", size(vsmall)) bar(1,color("166 183 39")) bar(2,color("246 146 0")) bar(3,color("223 83 39"))  bar(5,color("254 195 6"))  legend(size(small)) stack ylabel(0(0.1)1) 
graph save Graph "${output}/fig_18", replace
** table output to paste into excel
table16 money_barrier, c(mean fig18_1 mean fig18_2 mean fig18_3 mean fig18_4 mean fig18_5) 

** DISPLAY FIGURE 21  **********************************************************
use "CDG_2022_for_figures.dta",clear
egen x1=mean(ret_12mf) if eap&orggroup!="MP",by(orggroup)
egen x2=mean(ret_tvetmf) if eap&orggroup!="MP",by(orggroup)
egen x3=mean(ret_23mf) if eap&orggroup!="MP",by(orggroup)
drop if eap!=1
sort orggroup
drop if orggroup==orggroup[_n-1]
keep orggroup x1 x2 x3
drop if orggroup=="MP"
encode orggroup,gen(ni)
reshape long x, i(ni) j(level)
drop orggroup
reshape wide x, i(level) j(ni)
rename x1 x_moe
rename x2 x_mof
label define xlab 1 "Secondary vs. primary"  2 "TVET vs. secondary" 3 "University vs. secondary" 
label values level xlab
label var x_moe "MOE"
label var x_mof "MOF"
** Changing the order of levels to show same order as the excel figure
gen levels=4-level
label define xlabs 3 "Secondary vs. primary"  2 "TVET vs. secondary" 1 "University vs. secondary" 
label values levels xlabs
** stata figure - replicating excel figure
graph hbar x_mof x_moe , over(levels) legend(label(1 "MOF") label(2 "MOE")) ylabel(0 "0%" .2 "20%" .4 "40%" .6 "60%" .8 "80%" 1 "100%" 1.2 "120%" 1.4 "140%" 1.6 "160%",labsize(vsmall))  bar(1,color("166 183 39"))  bar(2,color("65 138 179"))
graph save Graph "${output}/fig_21", replace
** table output to paste into excel
table16 level,c(mean x_mof mean x_moe)

*** One needs to download all UIS data for figure 16 ***************************
** DISPLAY FIGURE 16 ***********************************************************
import excel "External_data.xlsx", sheet("GDP") firstrow clear
keep CountryCode YR2021
rename CountryCode cnt
rename YR2021 GDPc
destring GDPc, replace force
label var GDPc "Per capita GDP, PPP 2021"
label var cnt "Country code"
drop if cnt==""
save "perchildspending.dta",replace
import excel "External_data.xlsx", sheet("pop-WDI") firstrow clear
keep if Time=="2021"
rename CountryCode cnt
drop CountryName TimeCode Time
destring PopulationtotalSPPOPTOTL-Populationages1519maleSP,replace force
gen child_share=(Populationages0509maleSP+ Populationages0509femaleS+ Populationages1014femaleS+ Populationages1014maleSP+ Populationages1519femaleS+ Populationages1519maleSP)/PopulationtotalSPPOPTOTL
keep child_share cnt
label var child_share "Share of 5 to 19 in total population"
merge 1:1 cnt using "perchildspending.dta"
drop _merge
save "perchildspending.dta",replace
import excel "External_data.xlsx", sheet("UIS-sdg4") cellrange(B3:K191)  firstrow clear
keep Country K
rename K pub_funding_share_gdp
save "temp.dta",replace
import excel "External_data.xlsx", sheet("isocode") firstrow clear
merge 1:1 Country using "temp.dta"
drop if _merge!=3
drop _merge
merge 1:1 cnt using "perchildspending.dta"
drop _merge
gen perchildspending=pub_funding_share_gdp/100/child_share
gen lnyc=log(GDPc)
reg perchildspending lnyc
predict trend
** adding now EAP metrics
merge 1:1 cnt using "countries.dta"
gen eap_desired=pub_fund_desired/Actual_budget_share*perchildspending if CNT!=""&CNT!="Non-EAP"
gen eap_actual=perchildspending if CNT!=""&CNT!="Non-EAP"
replace Country="Lao PDR" if Country=="Lao People's Democratic Republic"
label var eap_actual "EAP actual"
label var eap_desired "EAP preferred by officials
label var perchildspending "Non-EAP countries"
twoway (scatter perchildspending GDPc) (line trend GDPc) (scatter eap_actual GDPc, mlabel(Country)) (scatter eap_desired GDPc, mlabel(Country)), xscale(log) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%", labsize(vsmall)) ytitle("Public funding for education by child as a proportion of per capita GDP", size(vsmall)) xlabel()
quietly: gen lngdpc = ln(GDPc)
quietly: reg perchildspending lngdpc if eap != 1
local r2 = round(1000 * `e(r2)') / 1000
di `r2'
drop lngdpc
twoway (scatter perchildspending GDPc,ms(Oh) mcolor(gray)) (line trend GDPc,lpattern(dot) lcolor(lavender)) (scatter eap_actual GDPc,mlabel(Country) mlabc(black) mlabsize(vsmall)) (scatter eap_desired GDPc,mlabel(Country) mlabc(black) mlabsize(vsmall)) , xscale(log) ylabel(0 "0%" .1 "10%" .2 "20%" .3 "30%" .4 "40%" .5 "50%",labsize(vsmall)) ytitle("Public funding for education by child as a proportion of per capita GDP",size(vsmall)) xlabel(500 2000 8000 32000 128000) text(0.4 90000   "R2=`r2'", placement(se) justification(left))
graph save Graph "${output}/fig_16", replace
** table output to paste into excel

table16 Country,c(mean perchildspending mean GDPc mean trend mean  eap_actual mean eap_desired)
help twoway

********************************************************************************
** 6 DCE EXPERIMENT 														****
********************************************************************************

** [6.1] Loading data

use "CGD_DCE_2022.dta",replace
destring vers_cbconjoint, replace force
sort vers_cbconjoint
mmerge vers_cbconjoint using  "CGD_DCE_joint.dta"
keep if _merge == 3

gen project_structuredreading = on ==1
gen project_inservice = on ==2
gen project_laptop = on ==3
gen project_lunch = on ==4
gen project_fee = on ==5
gen project_specialist = on ==6
gen project_hospital = on ==7

** Generate a choice dummy:
gen selected = 1 if question == 1 & scenario_project_1of5 == choice
replace selected = 1 if question == 2 & scenario_project_2of5 == choice
replace selected = 1 if question == 3 & scenario_project_3of5 == choice
replace selected = 1 if question == 4 & scenario_project_4of5 == choice
replace selected = 1 if question == 5 & scenario_project_5of5 == choice
*replace selected = 0 if selected !=.* 
recode selected .=0
 
gen male = respondent_gender == 1
gen hilevel = levelcode == 1

gen country_id = 11 if country == "Laos"
replace country_id = 12 if country == "Philippines"
replace country_id = 13 if country == "Indonesia"
replace country_id = 14 if country == "Mongolia"
replace country_id = 15 if country == "Vietnam"

replace country_id=0 if country_id==.
gen eap=country_id!=0


** Comparing projects between two areas
encode orggroup,gen(moe)
global controls5 male hilevel choice i.moe
global projects project_inservice project_laptop project_lunch project_fee project_specialist project_structuredreading
	
** [6.2] Unique regression
foreach var of varlist project_* {
gen `var'XEAP=`var'*eap
}
global projectsX project_structuredreadingX project_inserviceXEAP project_laptopXEAP project_lunchXEAP project_feeXEAP project_specialistXEAP
probit selected spending thatwill $controls5 eap $projects $projectsX , cluster(vers_cbconjoint)

** [6.3] Computing probabilities
** The figure is directly computed into excel using the estimates of the probit regression
** Sheet "Fig.5&14"

********************************************************************************
** 7 SEA-PLM MEAN SCORES													****
********************************************************************************
** Table 2 numbers
** Loading data file of students in stata format
use "SEA-PLM2019_students.dta",clear
** Computing average scores from plausible values
local list "read math write"
local list2 "R M W"
forvalues i=1/3 {
local x:word `i' of `list'
local y:word `i' of `list2'
gen `x'=0
forvalues j=1/5 {
replace `x'=`x'+PV`j'_`y'/5
}
}
** Gender labeling, 1 is "F" 2 is "M" according to student's questionnaire
destring Gender, replace force
label define genderlab 1 "Girl" 2 "Boy"
label values Gender genderlab
gen country="Cambodia" if cnt=="KHM"
replace country="Lao PDR" if cnt=="LAO"
replace country="Philippines" if cnt=="PHL"
replace country="Vietnam" if cnt=="VNM"
replace country="Malaysia" if cnt=="MYS"
replace country="Myanmar" if cnt=="MMR"  

table16 Gender country if Gender!=9 [iw=WT2019], c(mean read mean math mean write) format(%3.0f)

